==> fonts-sil-andika_6.101.orig.tar.xz: Andika-6.101/documentation/source/versions.md <==
---
title: Andika - Versions and Changes
fontversion: 6.101
---

## Announcement list

If you would like stay informed of updates to Andika and other SIL fonts, please subscribe to the [SIL Font News Announcement List](https://groups.google.com/a/groups.sil.org/forum/#!forum/sil-font-news). For more information see [About](about.md).

Our font announcements are also available through Twitter [@silfonts](http://twitter.com/silfonts).

## Current versions

The latest version of the fonts is always available from the [Andika download page](https://software.sil.org/andika/download/) as a .zip archive for all major platforms.

This font package is also available in the [SIL software repository for Ubuntu](https://packages.sil.org/). Users can subscribe to this software repository and get current versions and updates automatically.

Andika is also available through the [TypeTuner Web](https://scripts.sil.org/ttw/fonts2go.cgi) service, which allows you to choose among the smart font features and download a font with those features preset. TThis enables them to work in many applications that do not fully support OpenType.

## Special-purpose modified variants

- [Modified versions of the fonts](https://software.sil.org/lcgfonts/download/) are available that have been ‘tuned’ to turn on certain features by default. These are available for some regions and include *Literacy* and *Compact* versions.

## Version 5 subsets

Special versions of Andika version 5 were created for specific uses. Those fonts still work and remain available:

- [Font subsets](https://software.sil.org/lcgfonts/font-subsets/) are limited versions of the fonts that support only the characters needed for a particular area or use. Subsets are available for Africa, Americas, Asia/Pacific, Europe/Eurasia, Vietnam, Phonetic, Cyrillic (Basic) and Cyrillic Extended. With the exception of the Phonetic font, the font subsets are intended for orthographic use only. We have not put anything in the other subsets for phonetic, transliteration, or transcription use. For those purposes, use the Phonetic subset.

We do not intend to update these fonts to version 6, however they should continue to work. **If you have a need for any of these fonts to be updated to version 6 please [contact us](https://software.sil.org/andika/about/contact/).**

## Previous versions

Previous versions remain available from our [Previous Versions archive](https://software.sil.org/andika/download/previous-versions).

## Change history

A detailed list of changes for each version of the fonts is on the [Version history page](history.md).

==> fonts-sil-andika_6.200.orig.tar.xz: Andika-6.200/documentation/source/versions.md <==
---
title: Andika - Versions and Changes
fontversion: 6.200
---

## Announcement list

If you would like stay informed of updates to Andika and other SIL fonts, please subscribe to the [SIL Font News Announcement List](https://groups.google.com/a/groups.sil.org/forum/#!forum/sil-font-news). For more information see [About](about.md).

Our font announcements are also available through Twitter [\@silfonts](https://twitter.com/silfonts).

## Current versions

The latest version of the fonts is always available from the [Andika download page](https://software.sil.org/andika/download/) as a .zip archive for all major platforms.

This font package is also available in the [SIL software repository for Ubuntu](https://packages.sil.org/). Users can subscribe to this software repository and get current versions and updates automatically.

Andika is also available through the [TypeTuner Web](https://scripts.sil.org/ttw/fonts2go.cgi) service, which allows you to choose among the smart font features and download a font with those features preset. TThis enables them to work in many applications that do not fully support OpenType.

## Special-purpose modified variants

- [Modified versions of the fonts](https://software.sil.org/lcgfonts/download/) are available that have been ‘tuned’ to turn on certain features by default. These are available for some regions and include *Literacy* and *Compact* versions.  **These remain at version 6.101 and have not been updated to version 6.200. They will be updated at the next major version (7). If you need any of the new features or characters in this version, but also need them supported in the special-purpose modified fonts, please contact us.**

## Version 5 subsets

Special versions of Andika version 5 were created for specific uses. Those fonts still work and remain available:

- [Font subsets](https://software.sil.org/lcgfonts/font-subsets/) are limited versions of the fonts that support only the characters needed for a particular area or use. Subsets are available for Africa, Americas, Asia/Pacific, Europe/Eurasia, Vietnam, Phonetic, Cyrillic (Basic) and Cyrillic Extended. With the exception of the Phonetic font, the font subsets are intended for orthographic use only. We have not put anything in the other subsets for phonetic, transliteration, or transcription use. For those purposes, use the Phonetic subset.

We do not intend to update these fonts to version 6, however they should continue to work. **If you have a need for any of these fonts to be updated to version 6, please [contact us](https://software.sil.org/andika/about/contact/).**

## Previous versions

Previous versions remain available from our [Previous Versions archive](https://software.sil.org/andika/download/previous-versions).

## Change history

A detailed list of changes for each version of the fonts is on the [Version history page](history.md).
